@@ -51,6 +51,8 @@ logger = logging.getLogger('sentry.api.http')
 # See http://probablyprogramming.com/2009/03/15/the-tiniest-gif-ever
 PIXEL = 'R0lGODlhAQABAAD/ACwAAAAAAQABAAACADs='.decode('base64')
 
+PROTOCOL_VERSIONS = frozenset(('2.0', '3', '4', '5'))
+
 
 def api(func):
     @wraps(func)
@@ -103,7 +105,7 @@ class APIView(BaseView):
         server_version = auth_vars.get('sentry_version', '1.0')
         client = auth_vars.get('sentry_client', request.META.get('HTTP_USER_AGENT'))
 
-        if server_version not in ('2.0', '3', '4'):
+        if server_version not in PROTOCOL_VERSIONS:
             raise APIError('Client/server version mismatch: Unsupported protocol version (%s)' % server_version)
 
         if not client:
@@ -266,9 +268,13 @@ class StoreView(APIView):
     @never_cache
     def get(self, request, project, auth, **kwargs):
         data = request.GET.get('sentry_data', '')
-        self.process(request, project, auth, data, **kwargs)
-        # We should return a simple 1x1 gif for browser so they don't throw a warning
-        return HttpResponse(PIXEL, 'image/gif')
+        response_or_event_id = self.process(request, project, auth, data, **kwargs)
+
+        # Return a simple 1x1 gif for browser so they don't throw a warning
+        response = HttpResponse(PIXEL, 'image/gif')
+        if not isinstance(response_or_event_id, HttpResponse):
+            response['X-Sentry-ID'] = response_or_event_id
+        return response
 
     def process(self, request, project, auth, data, **kwargs):
         if safe_execute(app.quotas.is_rate_limited, project=project):
