@@ -17,29 +17,31 @@ import re
 
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.db.models import Q
 from django.http import HttpResponse, HttpResponseRedirect, Http404
 from django.shortcuts import get_object_or_404
 from django.utils import timezone
 
+from sentry import app
 from sentry.constants import (
     SORT_OPTIONS, SEARCH_SORT_OPTIONS, SORT_CLAUSES,
     MYSQL_SORT_CLAUSES, SQLITE_SORT_CLAUSES, MEMBER_USER,
     SCORE_CLAUSES, MYSQL_SCORE_CLAUSES, SQLITE_SCORE_CLAUSES,
     ORACLE_SORT_CLAUSES, ORACLE_SCORE_CLAUSES,
     MSSQL_SORT_CLAUSES, MSSQL_SCORE_CLAUSES, DEFAULT_SORT_OPTION,
-    SEARCH_DEFAULT_SORT_OPTION, MAX_JSON_RESULTS)
+    SEARCH_DEFAULT_SORT_OPTION, MAX_JSON_RESULTS
+)
 from sentry.db.models import create_or_update
 from sentry.filters import get_filters
 from sentry.models import (
-    Project, Group, Event, SearchDocument, Activity, EventMapping, TagKey,
-    GroupSeen)
+    Project, Group, Event, Activity, EventMapping, TagKey, GroupSeen
+)
 from sentry.permissions import can_admin_group, can_create_projects
 from sentry.plugins import plugins
 from sentry.utils import json
 from sentry.utils.dates import parse_date
 from sentry.utils.db import has_trending, get_db_engine
 from sentry.web.decorators import has_access, has_group_access, login_required
+from sentry.web.forms import NewNoteForm
 from sentry.web.helpers import render_to_response, group_is_public
 
 uuid_re = re.compile(r'^[a-z0-9]{32}$', re.I)
@@ -320,7 +322,7 @@ def search(request, team, project):
         #         'project': project,
         #     }, request)
     else:
-        documents = list(SearchDocument.objects.search(project, query, sort_by=sort))
+        documents = list(app.search.query(project, query, sort_by=sort))
         groups = Group.objects.in_bulk([d.group_id for d in documents])
 
         event_list = []
@@ -379,19 +381,31 @@ def group_list(request, team, project):
 def group(request, team, project, group, event_id=None):
     # It's possible that a message would not be created under certain
     # circumstances (such as a post_save signal failing)
-    activity_qs = Activity.objects.order_by('-datetime').select_related('user')
     if event_id:
         event = get_object_or_404(group.event_set, id=event_id)
-        activity_qs = activity_qs.filter(
-            Q(event=event) | Q(event__isnull=True),
-        )
     else:
         event = group.get_latest_event() or Event()
 
+    Event.objects.bind_nodes([event], 'data')
+
     # bind params to group in case they get hit
     event.group = group
     event.project = project
 
+    if request.POST.get('o') == 'note' and request.user.is_authenticated():
+        add_note_form = NewNoteForm(request.POST)
+        if add_note_form.is_valid():
+            add_note_form.save(event, request.user)
+            return HttpResponseRedirect(request.path)
+    else:
+        add_note_form = NewNoteForm()
+
+    activity_qs = Activity.objects.order_by('-datetime').select_related('user')
+    # if event_id:
+    #     activity_qs = activity_qs.filter(
+    #         Q(event=event) | Q(event__isnull=True),
+    #     )
+
     if project in Project.objects.get_for_user(
             request.user, team=team, superuser=False):
         # update that the user has seen this group
@@ -408,14 +422,22 @@ def group(request, team, project, group, event_id=None):
     # filter out dupe activity items
     activity_items = set()
     activity = []
-    for item in activity_qs.filter(group=group)[:10]:
+    for item in activity_qs.filter(group=group)[:20]:
         sig = (item.event_id, item.type, item.ident, item.user_id)
-        if sig not in activity_items:
+        # TODO: we could just generate a signature (hash(text)) for notes
+        # so theres no special casing
+        if item.type == Activity.NOTE:
+            activity.append(item)
+        elif sig not in activity_items:
             activity_items.add(sig)
             activity.append(item)
 
+    activity.append(Activity(
+        project=project, group=group, type=Activity.FIRST_SEEN,
+        datetime=group.first_seen))
+
     # trim to latest 5
-    activity = activity[:5]
+    activity = activity[:7]
 
     seen_by = sorted(filter(lambda ls: ls[0] != request.user and ls[0].email, [
         (gs.user, gs.last_seen)
@@ -429,6 +451,7 @@ def group(request, team, project, group, event_id=None):
     seen_by_faces = seen_by[:5]
 
     context = {
+        'add_note_form': add_note_form,
         'page': 'details',
         'activity': activity,
         'seen_by': seen_by,
@@ -481,7 +504,10 @@ def group_tag_details(request, team, project, group, tag_name):
 
 @has_group_access
 def group_event_list(request, team, project, group):
-    event_list = group.event_set.all().order_by('-datetime')
+    # TODO: we need the event data to bind after we limit
+    event_list = group.event_set.all().order_by('-datetime')[:100]
+
+    Event.objects.bind_nodes(event_list, 'data')
 
     return render_with_group_context(group, 'sentry/groups/event_list.html', {
         'event_list': event_list,
@@ -503,6 +529,8 @@ def group_event_list_json(request, team, project, group_id):
 
     events = group.event_set.order_by('-id')[:limit]
 
+    Event.objects.bind_nodes(events, 'data')
+
     return HttpResponse(json.dumps([event.as_dict() for event in events]), mimetype='application/json')
 
 
@@ -517,6 +545,8 @@ def group_event_details_json(request, team, project, group_id, event_id_or_lates
     else:
         event = get_object_or_404(group.event_set, pk=event_id_or_latest)
 
+    Event.objects.bind_nodes([event], 'data')
+
     return HttpResponse(json.dumps(event.as_dict()), mimetype='application/json')
 
 
